Enum Entry
pub enum Entry<'a, T>where
T: 'a,{
Occupied(OccupiedEntry<'a, T>),
Vacant(VacantEntry<'a, T>),
}Expand description
A view into a single location in a HeaderMap, which may be vacant or occupied.
Variants
Implementations
impl<'a, T> Entry<'a, T>
impl<'a, T> Entry<'a, T>
pub fn or_insert(self, default: T) -> &'a mut T
pub fn or_insert(self, default: T) -> &'a mut T
Ensures a value is in the entry by inserting the default if empty.
Returns a mutable reference to the first value in the entry.
Panics
This method panics if capacity exceeds max HeaderMap capacity
Examples
let mut map: HeaderMap<u32> = HeaderMap::default();
let headers = &[
"content-length",
"x-hello",
"Content-Length",
"x-world",
];
for &header in headers {
let counter = map.entry(header)
.or_insert(0);
*counter += 1;
}
assert_eq!(map["content-length"], 2);
assert_eq!(map["x-hello"], 1);pub fn or_try_insert(self, default: T) -> Result<&'a mut T, MaxSizeReached>
pub fn or_try_insert(self, default: T) -> Result<&'a mut T, MaxSizeReached>
Ensures a value is in the entry by inserting the default if empty.
Returns a mutable reference to the first value in the entry.
Errors
This function may return an error if HeaderMap exceeds max capacity
Examples
let mut map: HeaderMap<u32> = HeaderMap::default();
let headers = &[
"content-length",
"x-hello",
"Content-Length",
"x-world",
];
for &header in headers {
let counter = map.entry(header)
.or_try_insert(0)
.unwrap();
*counter += 1;
}
assert_eq!(map["content-length"], 2);
assert_eq!(map["x-hello"], 1);pub fn or_insert_with<F>(self, default: F) -> &'a mut Twhere
F: FnOnce() -> T,
pub fn or_insert_with<F>(self, default: F) -> &'a mut Twhere
F: FnOnce() -> T,
Ensures a value is in the entry by inserting the result of the default function if empty.
The default function is not called if the entry exists in the map. Returns a mutable reference to the first value in the entry.
Examples
Basic usage.
let mut map = HeaderMap::new();
let res = map.entry("x-hello")
.or_insert_with(|| "world".parse().unwrap());
assert_eq!(res, "world");The default function is not called if the entry exists in the map.
let mut map = HeaderMap::new();
map.try_insert(HOST, "world".parse().unwrap()).unwrap();
let res = map.try_entry("host")
.unwrap()
.or_try_insert_with(|| unreachable!())
.unwrap();
assert_eq!(res, "world");pub fn or_try_insert_with<F>(
self,
default: F,
) -> Result<&'a mut T, MaxSizeReached>where
F: FnOnce() -> T,
pub fn or_try_insert_with<F>(
self,
default: F,
) -> Result<&'a mut T, MaxSizeReached>where
F: FnOnce() -> T,
Ensures a value is in the entry by inserting the result of the default function if empty.
The default function is not called if the entry exists in the map. Returns a mutable reference to the first value in the entry.
Examples
Basic usage.
let mut map = HeaderMap::new();
let res = map.entry("x-hello")
.or_insert_with(|| "world".parse().unwrap());
assert_eq!(res, "world");The default function is not called if the entry exists in the map.
let mut map = HeaderMap::new();
map.try_insert(HOST, "world".parse().unwrap()).unwrap();
let res = map.try_entry("host")
.unwrap()
.or_try_insert_with(|| unreachable!())
.unwrap();
assert_eq!(res, "world");pub fn key(&self) -> &HeaderName
pub fn key(&self) -> &HeaderName
Returns a reference to the entryโs key
Examples
let mut map = HeaderMap::new();
assert_eq!(map.entry("x-hello").key(), "x-hello");Trait Implementations