Struct ToStrError
pub struct ToStrError {
_priv: (),
}Expand description
A possible error when converting a HeaderValue to a string representation.
Header field values may contain opaque bytes, in which case it is not possible to represent the value as a string.
Fields
_priv: ()Trait Implementations
impl Debug for ToStrError
impl Debug for ToStrError
impl Display for ToStrError
impl Display for ToStrError
impl Error for ToStrError
impl Error for ToStrError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
impl From<ToStrError> for Error
Available on crate feature handshake only.
impl From<ToStrError> for Error
Available on crate feature
handshake only.fn from(err: ToStrError) -> Error
fn from(err: ToStrError) -> Error
Converts to this type from the input type.
impl From<ToStrError> for LinkHeaderParseError
impl From<ToStrError> for LinkHeaderParseError
fn from(source: ToStrError) -> LinkHeaderParseError
fn from(source: ToStrError) -> LinkHeaderParseError
Converts to this type from the input type.